@@ -58,7 +58,6 @@ def xref_encode_with_keys(series, xref):
             series2[idx] = xref['forward'][str(val)]
         else:
             series2[idx] = None
-            if val not in skipped_vals: skipped_vals.append(val)
     if len(skipped_vals)>0:
         print('        WARNING! The following values were not present in the training encoding set and will be skipped: ', skipped_vals)
     return series2
@@ -205,7 +204,7 @@ def rref_decode(df, record_id_var, rref, verbose=False):
     if record_id_var not in df2.columns:
         df2[record_id_var] = df2.index
     series = df[record_id_var].squeeze() if isinstance(df[record_id_var], pd.DataFrame) else df[record_id_var]
-    df2[record_id_var] = xref_decode(series, rref)
+    df2[record_id_var] = xref_decode(series, rref, True)
     df2 = df2.set_index(record_id_var)
     return df2
 
@@ -348,6 +347,9 @@ def merge_cluster_ids(df, pc_id, idx_var):
     :param idx_var: name of record ID field
     :return df2:
     """
+    print('df...', df)
+    print('pc_id...', pc_id)
+    print(idx_var)
     return pd.merge(df, pc_id, left_on=idx_var, right_on=idx_var, how='left')
 
 def get_test_data():
